#
# spec file for package alsa-utils
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

#
%if %suse_version > 1130
%define use_systemd	1
%define use_varlib	1
%else
%define use_systemd	0
%define use_varlib	0
%endif

Name:           alsa-utils
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlto
%define package_version	1.0.25
Provides:       alsa-conf
Requires:       dialog pciutils alsa
Summary:        Advanced Linux Sound Architecture Utilities
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
Version:        1.0.25
Release:        2.1
Source:         ftp://ftp.alsa-project.org/pub/utils/alsa-utils-%{package_version}.tar.bz2
# Patch:          alsa-utils-git-fixes.diff
Patch99:        alsa-utils-gettext-version-removal.diff
Url:            http://www.alsa-project.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains utility programs supporting ALSA, Advanced Linux
Sound Architecture.

%prep
%setup -q -n %{name}-%{package_version}
# fix stupid automake's automatic action
sed -i -e's/EXTRA_DIST= config.rpath /EXTRA_DIST=/' Makefile.am
# rm -f po/Makefile* po/*.gmo po/*.pot po/*.header po/stamp-*
# patch -p1
%if %suse_version < 1020
%patch99 -p1
%endif

%build
export AUTOMAKE_JOBS="%{?_smp_mflags}"
%if %suse_version < 1020
gettextize -f
%endif
autoreconf -fi
opts=""
%if %use_systemd
opts="$opts --with-systemdsystemunitdir=/lib/systemd/system"
%endif
%if ! %use_varlib
opts="$opts --with-asound-state-dir=/etc"
%endif
%if %suse_version < 1030
opts="$opts --disable-xmlto"
%endif
%configure --with-curses=ncursesw $opts
make %{?_smp_mflags}

%install
%makeinstall
%find_lang %{name} --all-name
%if %use_systemd
ln -s alsa-restore.service $RPM_BUILD_ROOT/lib/systemd/system/alsasound.service
%endif
%if %use_varlib
mkdir -p $RPM_BUILD_ROOT/var/lib/alsa
%endif

%files -f %{name}.lang
%defattr(-, root, root)
%doc COPYING ChangeLog INSTALL README TODO
%doc seq/aconnect/README*
%doc seq/aseqnet/README*
%doc %{_mandir}/man*/*
%doc %{_mandir}/fr
%{_bindir}/*
%{_sbindir}/*
%{_datadir}/sounds/alsa
%{_datadir}/alsa
/lib/udev
%if %use_systemd
/lib/systemd
%endif
%if %use_varlib
/var/lib/alsa
%endif

%changelog
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; including all previous fixes
* Thu Dec 22 2011 crrodriguez@opensuse.org
- alsa-utils is of no use without alsa, add requires
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 tiwai@suse.de
- Fix missing initialization of Surround, etc, as well as Front
  Speaker, etc mixer elements in alsactl init
* Wed Nov  2 2011 tiwai@suse.de
- Backport upstream fix:
  - fix a crash of alsamixer with pulse plugin
* Tue Sep 20 2011 tiwai@suse.de
- Backport upstream fixes
  - Increase the max channels of aplay to 256.
  - Fix sed usage in Makefile.am
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Jun 28 2011 tiwai@suse.de
- Improved speaker-test man page
- Fix DB_RANGE TLV type handling in amixer
* Fri Jun  3 2011 tiwai@suse.de
- Backport alsa-utils fixes from upstream:
  0001-alsamixer-fix-display-of-active-inactive-controls.patch
  0002-alsaloop-libsamplerate-requires-specific-formats-for.patch
  0003-alsaloop-another-try-to-force-correct-formats-for-li.patch
  0004-alsamixer-fix-build-on-uClibc.patch
  0005-alsactl-init-Mute-CD-Playback-volume-by-default.patch
  0006-Revert-alsactl-Display-help-for-names-command.patch
  0007-alsaucm-Add-list1-command-for-non-tuple-lists.patch
  0008-alsaucm-Don-t-double-free-empty-lists.patch
  0009-aplay-Add-i-option-for-interactive-mode.patch
  0010-aplay-Avoid-recursive-signal-handling.patch
  0012-alsaloop-Use-AM_CFLAGS-in-Makefile.am.patch
  0013-Updated-COPYING-with-the-recent-FSF-address.patch
  0014-alsamixer-Fix-64bit-issues.patch
  0015-aplay-Add-include-files-for-mkdir.patch
  0016-aplay-Use-standard-endian-convesions.patch
* Mon Jan 31 2011 tiwai@suse.de
- updated to version 1.0.24.2:
  * including previous fixes
  * add UCM support
* Thu Dec  9 2010 tiwai@suse.de
- Use cubic scale for alsamixer volume bars for better usability
- Misc fixes from upstream
* Tue Nov 30 2010 tiwai@suse.de
- Add the missing /var/lib/alsa to filelist
* Fri Nov 26 2010 tiwai@suse.de
- add /lib/systemd/service/alsasound.service to make systemd
  skipping old sysv script
* Fri Nov 26 2010 tiwai@suse.de
- drop explicit buildrequires on systemd
* Fri Nov 26 2010 tiwai@suse.de
- backport GIT PATCHES:
  * A few alsactl init fix patches:
    0014-alsactl-init-Handle-Capture-Source-and-Mic-Boost-in-.patch
    0015-alsactl-init-Initialize-also-Master-Front-Playback-V.patch
  * amixer control-id parse fix
    0016-amixer-fix-parsing-of-control-ID-name.patch
  * new aloop utility
    0017-Introduce-alsaloop-utility.patch
    0018-alsaloop-Fix-loopbacks-pointer-initialization-and-al.patch
    0019-alsaloop-Fix-thread-handling.patch
    0020-alsaloop-fix-a-option-and-slave-mode-processing.patch
    0021-alsaloop-fix-resample-argument-parsing.patch
    0022-alsaloop-added-resampling-for-unsupported-soundcard-.patch
    0023-alsaloop-Add-OSS-mixer-redirection-support.patch
    0024-alsaloop-Fix-command-line-parsing-and-pollfd-initial.patch
    0025-alsaloop-Fixes-and-added-workaround-option.patch
    0026-alsaloop-add-pctl-and-cctl-options.patch
    0027-alsaloop-add-pctl-and-cctl-options-to-man-page.patch
    0028-alsaloop-added-xrun-profiling-support-U-xrun-added-S.patch
    0029-alsaloop-add-U-xrun-to-alsaloop.1-man-page.patch
    0030-alsaloop-fixes-added-W-wake-option.patch
    0031-alsaloop-Fix-latency-print.patch
    0033-alsaloop-Delay-the-restart-a-bit-to-handle-snd-aloop.patch
    0034-alsaloop-rework-the-ctl-event-handling-routine.patch
  * robusitfy speaker-test
    0032-speaker-test-Don-t-retry-after-fatal-errors.patch
  * misc clean up, translation updates
    0035-alsamixer-remove-obsolete-e-mail.patch
    0036-update-German-translations.patch
  * systemd integration
    0037-alsactl-systemd-and-udev-hookup.patch
    0038-alsactl-Move-asound.state-location-to-var-lib-alsa.patch
    0039-configure.in-Fix-variable-name.patch
- Use systemd for openSUSE 11.4
- Put udev rules into this package instead of alsa.rpm
* Thu Sep  2 2010 tiwai@suse.de
- backported GIT patches:
  * 0001-alsactl-use-snd_config_imake-functions.patch
  * 0002-alsactl-move-alloca-out-of-loop.patch
  * 0003-alsactl-remove-open-coded-search.patch
  * 0004-alsactl-correctly-restore-dB-values-of-controls-with.patch
  * 0005-alsactl-change-format-of-comment-node-in-state-file.patch
  * 0006-Revert-wrong-parts-of-alsactl-use-snd_config_imake-f.patch
  * 0007-aplay-arecord-Added-hardware-pause-support-press-SPA.patch
  * 0008-aplay-fix-termio-settings-return-back-old-c_flag-val.patch
  * 0009-speaker-test-add-test-pattern-for-PCM-layer-debuggin.patch
  * 0010-aplay-arecord-term_c_lflag-variable-might-be-unitial.patch
  * 0011-alsactl-init-Use-Found-hardware-instead-Unknown-hard.patch
  * 0012-alsactl-init-use-generic-method-instead-guess-method.patch
  * 0013-alsactl-Change-handling-of-inactive-controls.patch
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * including previous fixes
  * aconnect -x: Do not update index after removal of connection.
* Mon Mar  8 2010 tiwai@suse.de
- Backport upstream fixes:
  * aplay: Dump PCM state on xrun when verbose mode is active
  * aplay - add option --process-id-file
  * aplay -- add features for audio surveilance
  * aplay -- update the man file
  * amidi: fix port listing
  * speaker-test: add fflush(stdout) to write_loop
  * amixer: fix display of unreadable control elements
  * amixer: add support for TLV dB minmax types
  * alsactl: Fix return code
  * alsamixer: fix division by zero
  * alsamixer: handle out-of-range volume values
  * alsactl: improve -d to get warnings and store exitcode to runstate file
  * alsactl: add more debug prints to state.c
  * alsactl: update debug prints in state.c
* Fri Dec 18 2009 tiwai@suse.de
- set AUTOMAKE_JOBS for parallel automake
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  * including previous fixes
* Wed Sep  2 2009 tiwai@suse.de
- fix build with older distros; removed an obsolete patch
- fix alsactl init syntax errors in the default config
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Wed Aug 12 2009 tiwai@suse.de
- fix alsactl init Speaker volume setup
* Fri Jun 19 2009 tiwai@suse.de
- tricolorize alsamixer volumes
- fix alsactl init values
* Tue Jun  2 2009 tiwai@suse.de
- fix alsamixer man page about capture elements
* Fri May 29 2009 tiwai@suse.de
- sync with the upstream:
  * alsamixer code rewrite
  * more alsactl init fixes
  * translations updates
* Wed May 20 2009 tiwai@suse.de
- speaker-test minor clean-ups
- fix alsactl init headphone volume setup
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * including previous patches
  * a few more fixes about alsactl init command
* Thu Apr 23 2009 tiwai@suse.de
- updated as of 2009.04.23:
  * Added vi-like key bindings to alsamixer
  * alsactl/init: Fix CTL{value} assigning - make it relevant to
    documentation
  * aplay/arecord: improve suspicious buffer detection and add
  - -test-coef parameter
  * aplay/arecord: remove debug printfs introduced by previous
    patch
  * aplay/arecord: fix underrun/overrun time calculation for
    monotonic clock
* Wed Mar 18 2009 tiwai@suse.de
- add missing -I option for alsactl
- prefer /etc/modprobe.d/50-sound.conf for new module-init-tools
* Mon Feb 16 2009 tiwai@suse.de
- alsactl: init - modify default rule to better support some HDA
  codecs
- Fix build with partially-installed alsa-lib
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19
- use ANSI-C functions instead of index()
* Wed Nov 26 2008 tiwai@suse.de
- fix division-by-zero error in speaker-test program
* Wed Oct 29 2008 tiwai@suse.de
- updated to version 1.0.18-final;
  just including all previous fixes
* Thu Oct 23 2008 tiwai@suse.de
- added --test-position in aplay/arecord for debugging
- can disable the build of alsaconf in configure
- alsactl -g option to ignore 'no soundcards' error
* Thu Sep 11 2008 tiwai@suse.de
- fix possible segfaults during parsing in alsactl
* Wed Sep 10 2008 tiwai@suse.de
- updated to 1.0.18rc3:
  * more alsactl init implementations
* Wed Aug  6 2008 tiwai@suse.de
- alsactl init implementation (still non-working status, though)
- iecset utility updates for new IEC958 status bits
* Tue Jul 15 2008 tiwai@suse.de
- updated to 1.0.17-final:
  * just a version bump
* Wed Jun 18 2008 tiwai@suse.de
- updated to 1.0.17rc2:
  * including last fixes
* Wed Apr 16 2008 tiwai@suse.de
- HG snapshot 20080416:
  * fix a cast warning in aplay
  * use ncurses*-config in configure
* Fri Mar 14 2008 tiwai@suse.de
- HG snapshot 20080314:
  * stereo VU-meter support in aplay
* Mon Mar 10 2008 tiwai@suse.de
- HG snapshot 20080309:
  * support extensible WAV format in aplay
  * flush output in aseqdump
  * fix poll timeout in seq/* utils
  * clean up configure
* Wed Feb 13 2008 tiwai@suse.de
- clean up configure script
- add support of IEEE float in aplay/arecord
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16-rc1:
  * just a version bump
* Wed Jan  9 2008 tiwai@suse.de
- updated to HG 2008.01.09 version:
  * alsact: skip inactive controls
  * alsamixer: add 8-channel support
  * aplay, speaker-test: remove obsolete APIs
* Fri Dec 14 2007 tiwai@suse.de
- updated to HG 2007.12.14 version:
  * merged previous patches
  * fix blocking mode around snd_pcm_drain() calls in aplay
* Fri Nov 30 2007 tiwai@suse.de
- Merge upstream fixes:
  * make -F option as default for alsactl
  * fix iecset index range
  * fix a bug in alsactl restore that restores wrong values
* Mon Nov 12 2007 tiwai@suse.de
- fix double entries of comment.tlv in alsactl (#340516)
* Mon Nov  5 2007 tiwai@suse.de
- fix speaker-test with pulse plugin output
- use stderr for error message from speaker-test
* Mon Oct 29 2007 tiwai@suse.de
- make alsactl more robust
  * restore the volume values with channel changes
  * restore from dB level if available
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final
  * including all previous patches
* Mon Sep 17 2007 tiwai@suse.de
- fix the handling of capture enum elements in alsamixer (#325677)
* Tue Aug 14 2007 tiwai@suse.de
- amixer - Allow to pass enum item string for cset, too
- aplay - Include missing time.h for time()
* Mon Jul 30 2007 tiwai@suse.de
- HG fixes (as of 2007.07.28)
  * don't install hwcfg file for openSUSE 10.3 in alsaconf
  * fix the handling of enum channels in amixer
  * fix VU meter of aplay
  * fix possible infinite loop with signal handler in aplay
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final
  including previous HG fixes
* Thu May 24 2007 tiwai@suse.de
- HG patch as of 2007.05.24:
  * more error verbose messages in alsactl
  * fix duplicated mixer elements in alsamixer
- Use find_lang
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4
  including HG fixes
* Mon Apr 16 2007 tiwai@suse.de
- split from alsa package
